import os
from flask_migrate import Migrate, MigrateCommand
from flask_script import Manager

from .app import db
from .app import create_app

if os.path.exists("gunicorn.envfile"):
    print("Importing environment from .env...")
    for line in open("gunicorn.envfile"):
        var = line.strip().split("=")
        if len(var) == 2:
            os.environ[var[0]] = var[1]

app = create_app()

migrate = Migrate(app, db)
manager = Manager(app)

manager.add_command("db", MigrateCommand)


def main():
    manager.run()


if __name__ == "__main__":
    main()



"""empty message

Revision ID: ec190bd5da74
Revises: 9ced6e9ebd70
Create Date: 2021-03-31 15:31:03.333647

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql

# revision identifiers, used by Alembic.
revision = 'ec190bd5da74'
down_revision = '9ced6e9ebd70'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.alter_column('VM', 'reservation_start',
               existing_type=postgresql.TIMESTAMP(),
               nullable=True,
               existing_server_default=sa.text('now()'))
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.alter_column('VM', 'reservation_start',
               existing_type=postgresql.TIMESTAMP(),
               nullable=False,
               existing_server_default=sa.text('now()'))
    # ### end Alembic commands ###



# Python script that will apply the migrations up to head
import alembic.config
import os
import sys


from flask import current_app
from vm_booking_api import create_app, db

sys.path.append(os.getcwd())

here = os.path.dirname(os.path.abspath(__file__))

if os.path.exists("gunicorn.envfile"):
    print("Importing environment from .env...")
    for line in open("gunicorn.envfile"):
        var = line.strip().split("=")
        if len(var) == 2:
            os.environ[var[0]] = var[1]

try:
    app = current_app._get_current_object()
except RuntimeError:
    app = create_app()

alembic_args = ["-c", os.path.join(here, "alembic.ini"), "upgrade", "head"]
target_metadata = db.metadata


def main():
    with app.app_context():
        alembic.config.main(argv=alembic_args)
